// import QtQuick 1.0 // to target S60 5th Edition or Maemo 5
import QtQuick 1.1
import "../imports/XAComponents"
import "../Map"

Item {
    id: maincomponent

    property alias itemComment: commentInput.itemComment
    property alias itemPriority: priorityInput.itemPriority
    property alias itemColor: colorInput.itemColor
    property int itemAttachmentCount: 0

    property bool isEditable: false

    property bool isEditing: false
    property bool isModified: false
    property bool isSelected: false

    signal priorityTriggered(int newPriority);
    signal colorTriggered(int newColor);
    signal commentUpdated(string newComment);
    signal commentFocusRequested();

    property Gradient backgroundGradient: Gradient {
        GradientStop { position: 0.0; color: "white" }
        GradientStop { position: 1.0; color: "#d9d9d9" }
    }

    function deactivateEdit() {
        commentInput.focus = false
    }

    Rectangle {
        id: background
        anchors.fill: parent
        color: "transparent"

        AIActionDetailsPriorityInput {
            id: priorityInput
            anchors { left: parent.left; right: parent.right; top: parent.top; topMargin: 6 }
            height: 21

            onTriggered: {
                console.debug("Priority in Review Panel changed to: ")
                console.debug(newPriority)
                priorityTriggered(itemPriority)
            }
        }

        AIActionDetailsCommentInput {
            id: commentInput
            anchors { left: parent.left; right: parent.right; top: priorityInput.bottom; topMargin: 6 }
            height: 200

            zoomButtonVisible: true
            toolbarVisible: true

            onUpdated: {
                console.debug("Comment in Review Panel changed to: ")
                console.debug(newComment)
                commentUpdated(newComment)
            }
            onZoomRequested: QtHandler.zoom()
            onFocusRequested: commentFocusRequested();
        }

        AIActionDetailsColorInput {
            id: colorInput
            anchors { left: parent.left; right: parent.right; top: commentInput.bottom; topMargin: 6 }
            height: 200

            onTriggered: {
                console.debug("Color in Review Panel changed to: ")
                console.debug(newColor)
                colorTriggered(newColor)
            }
        }
    }
}
